summaryrefslogtreecommitdiffstats
path: root/examples/surfacechart/chartmodifier.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/surfacechart/chartmodifier.h')
-rw-r--r--examples/surfacechart/chartmodifier.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/surfacechart/chartmodifier.h b/examples/surfacechart/chartmodifier.h
index cb0a20a6..1de5840e 100644
--- a/examples/surfacechart/chartmodifier.h
+++ b/examples/surfacechart/chartmodifier.h
@@ -4,7 +4,7 @@
** All rights reserved.
** For any questions to Digia, please use contact form at http://qt.digia.com
**
** This file is part of the QtDataVis3D module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in
** accordance with the Qt Enterprise License Agreement provided with the
@@ -19,10 +19,10 @@
#ifndef CHARTMODIFIER_H
#define CHARTMODIFIER_H
-#include <QtDataVis3D/Q3DSurface>
+#include <QtDataVisualization/Q3DSurface>
#include <QSlider>
-using namespace QtDataVis3D;
+using namespace QtDataVisualization;
class ChartModifier : public QObject
{
@@ -4,7 +4,7 @@
** For any questions to Digia, please use contact form at http://qt.digia.com
**
-** This file is part of the QtDataVis3D module.
+** This file is part of the QtDataVisualization module.
**
** Licensees holding valid Qt Enterprise licenses may use this file in